<?php
/**
 * Plugin Name: Pro Pack for WP Job Openings
 * Description: Converts WP Job Openings to a powerful recruitment tool by adding some of the most sought features.
 * Author: AWSM Innovations
 * Author URI: https://awsm.in/
 * Version: 2.0.0
 * License: GPLv2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text domain: pro-pack-for-wp-job-openings
 * Domain Path: /languages
 */

/**
 * Pro Pack for WP Job Openings
 *
 * Converts WP Job Openings to a powerful recruitment tool by adding some of the most sought features.
 *
 * @package wp-job-openings
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// Plugin Constants
if ( ! defined( 'AWSM_JOBS_MAIN_PLUGIN' ) ) {
	define( 'AWSM_JOBS_MAIN_PLUGIN', 'wp-job-openings/wp-job-openings.php' );
}
if ( ! defined( 'AWSM_JOBS_PRO_PLUGIN_BASENAME' ) ) {
	define( 'AWSM_JOBS_PRO_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
}
if ( ! defined( 'AWSM_JOBS_PRO_PLUGIN_DIR' ) ) {
	define( 'AWSM_JOBS_PRO_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
}
if ( ! defined( 'AWSM_JOBS_PRO_PLUGIN_URL' ) ) {
	define( 'AWSM_JOBS_PRO_PLUGIN_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );
}
if ( ! defined( 'AWSM_JOBS_PRO_PLUGIN_VERSION' ) ) {
	define( 'AWSM_JOBS_PRO_PLUGIN_VERSION', '2.0.0' );
}
if ( ! defined( 'AWSM_JOBS_MAIN_REQ_VERSION' ) ) {
	define( 'AWSM_JOBS_MAIN_REQ_VERSION', '1.3' );
}
if ( ! defined( 'AWSM_JOBS_MAIN_REC_VERSION' ) ) {
	define( 'AWSM_JOBS_MAIN_REC_VERSION', '1.6.0' );
}

class AWSM_Job_Openings_Pro_Pack {
	private static $instance = null;

	public function __construct() {
		add_action( 'wp_loaded', array( $this, 'remove_hooks' ) );
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		add_action( 'admin_init', array( $this, 'handle_plugin_activation' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_action( 'init', array( $this, 'export_applications_handler' ), 100 );
		add_action( 'restrict_manage_posts', array( $this, 'export_applications_form' ) );
		add_action( 'admin_head', array( $this, 'remove_submenu_pages' ) );
		add_action( 'admin_init', array( $this, 'license_migration_handler' ) );
		add_action( 'admin_notices', array( $this, 'plugin_notices' ) );

		add_filter( 'plugin_action_links_' . AWSM_JOBS_PRO_PLUGIN_BASENAME, array( $this, 'plugin_action_links' ), 100 );
		add_filter( 'awsm_job_query_args', array( $this, 'jobs_query_args' ), 10, 3 );
		add_action( 'after_awsm_job_details', array( $this, 'back_to_listings' ) );
	}

	public static function init() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	public static function load_classes() {
		require_once AWSM_JOBS_PRO_PLUGIN_DIR . '/inc/class-awsm-job-openings-pro-main.php';
		require_once AWSM_JOBS_PRO_PLUGIN_DIR . '/inc/class-awsm-job-openings-pro-form.php';

		// WPML support.
		if ( defined( 'ICL_SITEPRESS_VERSION' ) ) {
			require_once AWSM_JOBS_PRO_PLUGIN_DIR . '/inc/translation/class-awsm-job-openings-pro-wpml.php';
		}

		// Admin classes.
		if ( is_admin() ) {
			require_once AWSM_JOBS_PRO_PLUGIN_DIR . '/inc/class-awsm-job-openings-pro-meta.php';
			require_once AWSM_JOBS_PRO_PLUGIN_DIR . '/inc/class-awsm-job-openings-pro-settings.php';
		}
	}

	public function activate() {
		if ( defined( 'AWSM_JOBS_PLUGIN_DIR' ) ) {
			if ( ! class_exists( 'AWSM_Job_Openings_Settings' ) ) {
				require_once AWSM_JOBS_PLUGIN_DIR . '/admin/class-awsm-job-openings-settings.php';
			}
			if ( ! class_exists( 'AWSM_Job_Openings_Pro_Settings' ) ) {
				require_once AWSM_JOBS_PRO_PLUGIN_DIR . '/inc/class-awsm-job-openings-pro-settings.php';
			}
			AWSM_Job_Openings_Pro_Settings::register_pro_defaults();
		}
	}

	public function plugins_loaded() {
		// load classes
		if ( class_exists( 'AWSM_Job_Openings' ) ) {
			self::load_classes();
		}
		// load translated strings
		load_plugin_textdomain( 'pro-pack-for-wp-job-openings', false, basename( dirname( __FILE__ ) ) . '/languages' );
	}

	public function remove_hooks() {
		if ( class_exists( 'AWSM_Job_Openings' ) ) {
			remove_action( 'admin_notices', array( AWSM_Job_Openings::init(), 'plugin_rating_notice_handler' ) );
		}
	}

	public function plugin_notices() {
		$this->license_migration_notices();
		$this->plugin_rating_notice_handler();
	}

	public function plugin_rating_notice_handler() {
		$rated = intval( get_option( 'awsm_jobs_plugin_rating' ) );
		if ( class_exists( 'AWSM_Job_Openings' ) && $rated !== 1 ) {
			$rating_url = 'https://wordpress.org/support/plugin/wp-job-openings/reviews/?filter=5';
			$rating_env = 'WordPress';

			// Job Context.
			AWSM_Job_Openings::plugin_rating_notice( $rating_url, $rating_env );

			// Application context.
			AWSM_Job_Openings::plugin_rating_notice( $rating_url, $rating_env, 'application' );
		}
	}

	public function plugin_action_links( $actions ) {
		if ( function_exists( 'awsm_jobs_pro_fs' ) ) {
			unset( $actions['activate-license pro-pack-for-wp-job-openings'] );
			$link_text = awsm_jobs_pro_fs()->is_free_plan() ? __( 'Activate License', 'pro-pack-for-wp-job-openings' ) : __( 'Manage License', 'pro-pack-for-wp-job-openings' );
			$link      = sprintf( '<a href="%1$s">%2$s</a>', esc_url( admin_url( 'edit.php?post_type=awsm_job_openings&page=awsm-jobs-settings&tab=license' ) ), esc_html( $link_text ) );
			array_unshift( $actions, $link );
		}
		return $actions;
	}

	public function remove_submenu_pages() {
		remove_submenu_page( 'edit.php?post_type=awsm_job_openings', 'awsm-jobs-settings-account' );
		remove_submenu_page( 'edit.php?post_type=awsm_job_openings', 'awsm-jobs-settings-contact' );
	}

	public function license_migration_handler() {
		if ( isset( $_GET['awsm_pro_activate'] ) && ! empty( $_GET['awsm_pro_activate'] ) ) {
			check_admin_referer( 'awsm_pro_migration_handler', 'awsm_pro_migration_handler_nonce' );
			if ( ! current_user_can( 'manage_options' ) ) {
				wp_die( esc_html__( 'You do not have sufficient permissions to make this request!', 'wp-job-openings' ) );
			}
			update_option( 'awsm_jobs_pro_migrate_license', 'migrated' );
			wp_safe_redirect( admin_url( 'edit.php?post_type=awsm_job_openings&page=awsm-jobs-settings&tab=license' ) );
			exit;
		}
	}

	public function license_migration_notices() {
		$hide_notice = false;

		$screen = get_current_screen();
		if ( ! empty( $screen ) ) {
			if ( $screen->base === 'update-core' || ( method_exists( $screen, 'is_block_editor' ) && $screen->is_block_editor() ) ) {
				$hide_notice = true;
			}
		}
		if ( function_exists( 'awsm_jobs_pro_fs' ) ) {
			if ( awsm_jobs_pro_fs()->can_use_premium_code() ) {
				$hide_notice = true;
			}
		}
		if ( ! current_user_can( 'manage_options' ) ) {
			$hide_notice = true;
		}

		/**
		 * Filters the license migration notice visibility.
		 *
		 * @since 2.0.0
		 *
		 * @param string $hide_notice Hide the migration notice or not.
		 */
		$hide_notice = apply_filters( 'awsm_jobs_pro_hide_migration_notice', $hide_notice );

		if ( ! $hide_notice ) :
			$activation_url = wp_nonce_url( add_query_arg( 'awsm_pro_activate', 'true', admin_url() ), 'awsm_pro_migration_handler', 'awsm_pro_migration_handler_nonce' );
			?>
			<div class="notice notice-warning">
				<h2><?php esc_html_e( 'Important Announcement from WP Job Openings Plugin', 'pro-pack-for-wp-job-openings' ); ?></h2>
				<p>
					<?php esc_html_e( 'We are migrating Pro Pack for WP Job Openings from Envato Marketplace to our own marketplace. So as part of this change we are offering a LIFETIME License worth $99 for all our existing customers who own a license from Envato Marketplace. Please click \'Get License\' button to get your brand new license. If you have already converted the license, click the \'Activate Now\' button to activate the converted license.', 'pro-pack-for-wp-job-openings' ); ?>
				</p>
				<p>
					<a href="https://wpjobopenings.com/license" class="button" target="_blank" rel="noopener noreferrer"><?php esc_html_e( 'Get License', 'pro-pack-for-wp-job-openings' ); ?></a>
					<a href="<?php echo esc_url( $activation_url ); ?>" class="button"><?php esc_html_e( 'Activate Now', 'pro-pack-for-wp-job-openings' ); ?></a>
				</p>
			</div>
			<?php
		endif;
	}

	public function get_main_plugin_activation_link( $is_update = false ) {
		$content = $link_action = $action_url = $link_class = ''; // phpcs:ignore Squiz.PHP.DisallowMultipleAssignments.Found

		if ( ! $is_update ) {
			// when plugin is not active.
			$link_action = esc_html__( 'Activate', 'pro-pack-for-wp-job-openings' );
			$action_url  = wp_nonce_url( self_admin_url( 'plugins.php?action=activate&plugin=' . AWSM_JOBS_MAIN_PLUGIN ), 'activate-plugin_' . AWSM_JOBS_MAIN_PLUGIN );
			$link_class  = ' activate-now';

			// when plugin is not installed.
			$plugin_arr       = explode( '/', esc_html( AWSM_JOBS_MAIN_PLUGIN ) );
			$plugin_slug      = $plugin_arr[0];
			$installed_plugin = get_plugins( '/' . $plugin_slug );
			if ( empty( $installed_plugin ) ) {
				if ( get_filesystem_method( array(), WP_PLUGIN_DIR ) === 'direct' ) {
					$link_action = esc_html__( 'Install', 'pro-pack-for-wp-job-openings' );
					$action_url  = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=' . $plugin_slug ), 'install-plugin_' . $plugin_slug );
					$link_class  = ' install-now';
				}
			}
		} else {
			// when plugin needs an update.
			$link_action = esc_html__( 'Update', 'pro-pack-for-wp-job-openings' );
			$action_url  = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' . AWSM_JOBS_MAIN_PLUGIN ), 'upgrade-plugin_' . AWSM_JOBS_MAIN_PLUGIN );
			$link_class  = ' update-now';
		}

		if ( ! empty( $link_action ) && ! empty( $action_url ) && ! empty( $link_class ) ) {
			$content = sprintf( '<a href="%2$s" class="button button-small%3$s">%1$s</a>', esc_html( $link_action ), esc_url( $action_url ), esc_attr( $link_class ) );
		}
		return $content;
	}

	public function admin_notices( $is_default = true, $req_plugin_version = AWSM_JOBS_MAIN_REQ_VERSION ) {
		?>
		<div class="updated error">
				<p>
					<?php
						$req_plugin = sprintf( '<strong>"%s"</strong>', esc_html__( 'WP Job Openings', 'pro-pack-for-wp-job-openings' ) );
						$plugin     = sprintf( '<strong>"%s"</strong>', esc_html__( 'Pro Pack for WP Job Openings', 'pro-pack-for-wp-job-openings' ) );
					if ( $is_default ) {
						/* translators: %1$s: main plugin, %2$s: current plugin, %3$s: plugin activation link, %4$s: line break */
						printf( esc_html__( 'The plugin %2$s needs the plugin %1$s active. %4$s Please %3$s %1$s', 'pro-pack-for-wp-job-openings' ), $req_plugin, $plugin, $this->get_main_plugin_activation_link(), '<br />' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					} else {
						/* translators: %1$s: main plugin, %2$s: current plugin, %3$s: minimum required version of the main plugin, %4$s: plugin updation link */
						printf( esc_html__( '%2$s plugin requires %1$s version %3$s. Please %4$s %1$s plugin to the latest version.', 'pro-pack-for-wp-job-openings' ), $req_plugin, $plugin, esc_html( $req_plugin_version ), $this->get_main_plugin_activation_link( true ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
					?>
				</p>
			</div>
		<?php
	}

	public function handle_plugin_activation() {
		include_once ABSPATH . 'wp-admin/includes/plugin.php';
		if ( is_plugin_inactive( AWSM_JOBS_MAIN_PLUGIN ) || ! class_exists( 'AWSM_Job_Openings' ) ) {
			add_action(
				'admin_notices',
				function() {
					$this->admin_notices();
				}
			);
			deactivate_plugins( AWSM_JOBS_PRO_PLUGIN_BASENAME );
		}
		if ( defined( 'AWSM_JOBS_PLUGIN_VERSION' ) ) {
			if ( version_compare( AWSM_JOBS_PLUGIN_VERSION, AWSM_JOBS_MAIN_REQ_VERSION, '<' ) ) {
				add_action(
					'admin_notices',
					function() {
						$this->admin_notices( false );
					}
				);
				deactivate_plugins( AWSM_JOBS_PRO_PLUGIN_BASENAME );
			}
		}
	}

	public function enqueue_scripts() {
		wp_enqueue_style( 'awsm-job-pro-style', AWSM_JOBS_PRO_PLUGIN_URL . '/assets/css/style.min.css', array( 'awsm-jobs-style' ), AWSM_JOBS_PRO_PLUGIN_VERSION, 'all' );

		wp_enqueue_script( 'awsm-job-pro-scripts', AWSM_JOBS_PRO_PLUGIN_URL . '/assets/js/script.min.js', array( 'jquery', 'awsm-job-scripts' ), AWSM_JOBS_PRO_PLUGIN_VERSION, true );
	}

	public function admin_enqueue_scripts() {
		$screen    = get_current_screen();
		$post_type = false;
		if ( ! empty( $screen ) ) {
			$post_type = $screen->post_type;
		}
		wp_register_style( 'awsm-job-pro-admin-global', AWSM_JOBS_PRO_PLUGIN_URL . '/assets/css/admin-global.min.css', array(), AWSM_JOBS_PRO_PLUGIN_VERSION, 'all' );
		wp_register_style( 'awsm-job-pro-admin', AWSM_JOBS_PRO_PLUGIN_URL . '/assets/css/admin.min.css', array( 'awsm-job-admin', 'awsm-job-pro-admin-global' ), AWSM_JOBS_PRO_PLUGIN_VERSION, 'all' );

		wp_register_script( 'awsm-job-pro-jspdf', AWSM_JOBS_PRO_PLUGIN_URL . '/assets/js/jspdf.umd.min.js', array(), '2.1.1', true );
		$admin_deps = array( 'jquery', 'jquery-ui-sortable', 'awsm-job-admin', 'wp-util' );
		if ( $post_type && $post_type === 'awsm_job_application' && $screen->base === 'post' ) {
			$admin_deps[] = 'awsm-job-pro-jspdf';
		}
		wp_register_script( 'awsm-job-pro-admin', AWSM_JOBS_PRO_PLUGIN_URL . '/assets/js/admin.min.js', $admin_deps, AWSM_JOBS_PRO_PLUGIN_VERSION, true );

		wp_enqueue_style( 'awsm-job-pro-admin-global' );
		if ( $post_type && ( $post_type === 'awsm_job_openings' ) || ( $post_type === 'awsm_job_application' ) ) {
			wp_enqueue_style( 'awsm-job-pro-admin' );
			wp_enqueue_script( 'awsm-job-pro-admin' );
		}

		wp_localize_script(
			'awsm-job-pro-admin',
			'awsmProJobsAdmin',
			array(
				'nonce' => wp_create_nonce( 'awsm-pro-admin-nonce' ),
				'i18n'  => array(),
			)
		);
	}

	public function export_applications_form( $post_type ) {
		if ( current_user_can( 'edit_others_applications' ) && $post_type === 'awsm_job_application' ) :
			$query_vars   = array(
				'awsm_nonce'  => wp_create_nonce( 'awsm_export_nonce' ),
				'awsm_action' => 'export_applications',
			);
			$download_url = add_query_arg( $query_vars );
			?>
			<a href="<?php echo esc_url( $download_url ); ?>" class="button awsm-export-applications-btn button-primary" style="display:none;" rel="nofollow"><strong><?php esc_html_e( 'Export Applications', 'pro-pack-for-wp-job-openings' ); ?></strong></a>
			<?php
		endif;
	}

	public function export_applications_handler() {
		if ( isset( $_GET['awsm_action'] ) && $_GET['awsm_action'] === 'export_applications' ) {
			if ( ! is_user_logged_in() || ! current_user_can( 'edit_others_applications' ) ) {
				wp_die( esc_html__( 'You are not authorized to make this request!', 'pro-pack-for-wp-job-openings' ) );
			}

			if ( ! isset( $_GET['awsm_nonce'] ) || ! wp_verify_nonce( $_GET['awsm_nonce'], 'awsm_export_nonce' ) ) {
				wp_die( esc_html__( 'Invalid request!', 'pro-pack-for-wp-job-openings' ) );
			}

			$args = array(
				'post_type'      => 'awsm_job_application',
				'post_status'    => 'any',
				'posts_per_page' => -1,
				'order'          => 'ASC',
				'orderby'        => 'ID',
			);
			// Handle application status.
			if ( isset( $_GET['post_status'] ) && ! empty( $_GET['post_status'] ) ) {
				$args['post_status'] = sanitize_text_field( $_GET['post_status'] );
			}
			// Handle meta queries.
			$meta_query = array();
			$job_filter = isset( $_GET['awsm_filter_posts'] ) ? intval( $_GET['awsm_filter_posts'] ) : '';
			if ( ! empty( $job_filter ) && get_post_type( $job_filter ) === 'awsm_job_openings' ) {
				$meta_query[] = array(
					'key'   => 'awsm_job_id',
					'value' => $job_filter,
				);
			}
			if ( ! empty( $meta_query ) ) {
				$args['meta_query'] = $meta_query;
			}

			$applications = get_posts( $args );

			if ( ! empty( $applications ) ) {
				// Generate Header.
				$data       = array(
					array(
						'awsm_application_id'   => esc_html__( 'Application ID', 'pro-pack-for-wp-job-openings' ),
						'awsm_applicant_name'   => esc_html__( 'Applicant Name', 'pro-pack-for-wp-job-openings' ),
						'awsm_applicant_email'  => esc_html__( 'Email', 'pro-pack-for-wp-job-openings' ),
						'awsm_job_id'           => esc_html__( 'Job ID', 'pro-pack-for-wp-job-openings' ),
						'awsm_apply_for'        => esc_html__( 'Job Title', 'pro-pack-for-wp-job-openings' ),
						'awsm_application_date' => esc_html__( 'Applied on', 'pro-pack-for-wp-job-openings' ),
					),
				);
				$fb_options = get_option( 'awsm_jobs_form_builder' );
				if ( empty( $fb_options ) ) {
					$fb_options = array();
					if ( method_exists( 'AWSM_Job_Openings_Pro_Settings', 'form_builder_default_options' ) ) {
						$fb_options = AWSM_Job_Openings_Pro_Settings::form_builder_default_options();
					}
				}
				foreach ( $fb_options as $fb_option ) {
					if ( $fb_option['name'] !== 'awsm_applicant_name' && $fb_option['name'] !== 'awsm_applicant_email' ) {
						$data[0][ $fb_option['name'] ] = $fb_option['label'];
					}
				}
				$data[0]['application_status'] = esc_html__( 'Status', 'pro-pack-for-wp-job-openings' );

				// Now, generate content.
				foreach ( $applications as $application ) {
					$application_id    = $application->ID;
					$applicant_details = array();

					// Fixed fields.
					$applicant_details['awsm_application_id'] = $application_id;
					$general_fields                           = array( 'awsm_applicant_name', 'awsm_applicant_email', 'awsm_job_id', 'awsm_apply_for' );
					foreach ( $general_fields as $general_field ) {
						$applicant_details[ $general_field ] = get_post_meta( $application_id, $general_field, true );
					}
					$applicant_details['awsm_application_date'] = get_the_date( '', $application_id );

					// Custom fields.
					$custom_fields = get_post_meta( $application_id, 'awsm_applicant_custom_fields', true );
					foreach ( $fb_options as $fb_option ) {
						if ( $fb_option['super_field'] !== true ) {
							$field_value = '';
							$name        = $fb_option['name'];
							$field_type  = $fb_option['field_type'];
							if ( $fb_option['default_field'] !== true ) {
								if ( isset( $custom_fields[ $name ]['value'] ) ) {
									$field_value = $custom_fields[ $name ]['value'];
									if ( $field_type === 'photo' || $field_type === 'file' ) {
										$field_value = ! empty( $field_value ) ? wp_get_attachment_url( $field_value ) : '';
									}
								}
							} else {
								if ( $field_type === 'resume' ) {
									$attachment_id = get_post_meta( $application_id, 'awsm_attachment_id', true );
									$field_value   = ! empty( $attachment_id ) ? wp_get_attachment_url( $attachment_id ) : '';
								} else {
									$field_value = get_post_meta( $application_id, $name, true );
								}
							}
							if ( empty( $field_value ) ) {
								$field_value = esc_html__( 'NA', 'pro-pack-for-wp-job-openings' );
							}
							$applicant_details[ $name ] = $field_value;
						}
					}
					$post_status = get_post_status( $application_id );
					if ( method_exists( 'AWSM_Job_Openings_Pro_Main', 'get_application_status' ) ) {
						$available_status = AWSM_Job_Openings_Pro_Main::get_application_status();
						if ( isset( $available_status[ $post_status ] ) ) {
							$post_status = $available_status[ $post_status ]['label'];
						}
					}
					$applicant_details['application_status'] = $post_status;

					$data[] = $applicant_details;
				}
				$file_name = sanitize_file_name( 'job-applications-' . current_time( 'Y-m-d' ) . '.csv' );
				header( 'Content-Encoding: UTF-8' );
				header( 'Content-Type: text/csv; charset=utf-8' );
				header( 'Content-Disposition: attachment; filename="' . $file_name . '"' );
				header( 'Pragma: no-cache' );
				header( 'Expires: 0' );
				$file = fopen( 'php://output', 'w' );
				foreach ( $data as $rows ) {
					fputcsv( $file, $rows );
				}
				exit;
			}
		}
	}

	public function jobs_query_args( $args, $filters, $shortcode_atts ) {
		$spec_details = isset( $shortcode_atts['specs'] ) ? $shortcode_atts['specs'] : '';
		if ( ! empty( $spec_details ) ) {
			$specs = explode( ',', $spec_details );
			foreach ( $specs as $spec ) {
				if ( strpos( $spec, ':' ) !== false ) {
					list( $taxonomy, $spec_terms ) = explode( ':', $spec );
					$args['tax_query'][]           = array(
						'taxonomy' => sanitize_text_field( $taxonomy ),
						'field'    => 'id',
						'terms'    => array_map( 'intval', explode( ' ', $spec_terms ) ),
					);
				}
			}
		}
		return $args;
	}

	public function back_to_listings() {
		$default_page  = get_option( 'awsm_jobs_default_listing_page_id' );
		$selected_page = get_option( 'awsm_select_page_listing', $default_page );
		$enable_link   = get_option( 'awsm_jobs_back_to_listings' );
		if ( $enable_link === 'enable' ) {
			$link_content = sprintf( '<div class="awsm-jobs-pro-listings-link-container"><a href="%2$s" class="awsm-jobs-pro-listings-link">%1$s</a></div>', esc_html__( 'Back to listings', 'pro-pack-for-wp-job-openings' ), esc_url( get_page_link( $selected_page ) ) );
			/**
			 * Filters the back to job listings link HTML content.
			 *
			 * @since 2.0.0
			 *
			 * @param string $link_content Link HTML content.
			 */
			echo apply_filters( 'awsm_jobs_pro_back_to_listings_link_content', $link_content );
		}
	}
}

$license_migrated = get_option( 'awsm_jobs_pro_migrate_license' );
if ( ! empty( $license_migrated ) && $license_migrated === 'migrated' ) {
	// SDK Integration.
	if ( ! function_exists( 'awsm_jobs_pro_fs' ) ) {
		function awsm_jobs_pro_fs() {
			global $awsm_jobs_pro_fs;

			if ( ! isset( $awsm_jobs_pro_fs ) ) {
				// Include Freemius SDK.
				require_once dirname( __FILE__ ) . '/lib/freemius/start.php';

				$fs_secret_key = defined( 'AWSM_JOBS_PRO_FS_SECRET_KEY' ) ? AWSM_JOBS_PRO_FS_SECRET_KEY : '';

				$awsm_jobs_pro_fs = fs_dynamic_init(
					array(
						'id'               => '6983',
						'slug'             => 'pro-pack-for-wp-job-openings',
						'premium_slug'     => 'pro-pack-for-wp-job-openings',
						'type'             => 'plugin',
						'public_key'       => 'pk_6a0040329e377a4898234a800e108',
						'is_premium'       => true,
						'is_premium_only'  => true,
						'has_addons'       => false,
						'has_paid_plans'   => true,
						'is_org_compliant' => false,
						'navigation'       => 'tabs',
						'menu'             => array(
							'slug'           => 'awsm-jobs-settings',
							'override_exact' => true,
							'support'        => false,
							'parent'         => array(
								'slug' => 'edit.php?post_type=awsm_job_openings',
							),
						),
						// Development only.
						'secret_key'       => $fs_secret_key,
					)
				);
			}

			return $awsm_jobs_pro_fs;
		}

		// Init Freemius.
		awsm_jobs_pro_fs();
		// Signal that SDK was initiated.
		do_action( 'awsm_jobs_pro_fs_loaded' );

		function awsm_jobs_pro_fs_uninstall_cleanup() {
			if ( get_option( 'awsm_delete_data_on_uninstall' ) !== 'delete_data' ) {
				return;
			}

			require_once dirname( __FILE__ ) . '/inc/class-awsm-job-openings-pro-uninstall.php';

			if ( class_exists( 'AWSM_Job_Openings_Pro_Uninstall' ) ) {
				AWSM_Job_Openings_Pro_Uninstall::pro_uninstall();
			}
		}

		function awsm_jobs_pro_fs_is_submenu_visible( $is_visible, $submenu_id ) {
			if ( $submenu_id === 'pricing' ) {
				$is_visible = false;
			}
			return $is_visible;
		}

		function awsm_jobs_pro_fs_settings_url() {
			return admin_url( 'edit.php?post_type=awsm_job_openings&page=awsm-jobs-settings&tab=license' );
		}

		awsm_jobs_pro_fs()->add_action( 'after_uninstall', 'awsm_jobs_pro_fs_uninstall_cleanup' );

		awsm_jobs_pro_fs()->add_filter( 'is_submenu_visible', 'awsm_jobs_pro_fs_is_submenu_visible', 10, 2 );
		awsm_jobs_pro_fs()->add_filter( 'connect_url', 'awsm_jobs_pro_fs_settings_url' );
		awsm_jobs_pro_fs()->add_filter( 'after_skip_url', 'awsm_jobs_pro_fs_settings_url' );
		awsm_jobs_pro_fs()->add_filter( 'after_connect_url', 'awsm_jobs_pro_fs_settings_url' );
		awsm_jobs_pro_fs()->add_filter( 'after_pending_connect_url', 'awsm_jobs_pro_fs_settings_url' );
	}
}

// Initialize the class.
$awsm_pro_job_openings = AWSM_Job_Openings_Pro_Pack::init();

// Handle plugin activation.
register_activation_hook( __FILE__, array( $awsm_pro_job_openings, 'activate' ) );
